# Mathsimple

Este é um pacote de exemplo para realizar operações matemáticas simples: adição e subtração.

## Instalação

```bash
pip install alissonimplemath
```

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

## Usage

```
from mathsimple import somar, subtrair

print(somar(2, 3))      # Saída: 5
print(subtrair(5, 3))   # Saída: 2
```

## Author
[Alisson Guarniêr Araújo Faria](https://github.com/alissonguarnier)

## License
[MIT](https://choosealicense.com/licenses/mit/)
